aboutsummaryrefslogtreecommitdiff
path: root/main.go
diff options
context:
space:
mode:
Diffstat (limited to 'main.go')
-rw-r--r--main.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/main.go b/main.go
index 5c25fa4..ee73186 100644
--- a/main.go
+++ b/main.go
@@ -2,7 +2,7 @@
//
// Install:
//
// go install git.cs.kau.se/rasmoste/ct-sans@latest
//
// Usage:
//
@@ -16,7 +16,7 @@ import (
"os"
"time"
- "git.cs.kau.se/rasmoste/ct-sans/internal/ctflag"
+ "rgdd.se/ct-sans/internal/ctflag"
)
const usage = `ct-sans collects SANs in CT-logged certificates
@@ -46,7 +46,7 @@ Collect options:
-w, --workers: Max number of parallel download workers per log (Default: 2).
-k, --batch-disk: Certificate batch size before persisting (Default: 256)
-q, --batch-req: Certificate batch size to use in request (Default: 128)
- -a, --http-agent: HTTP agent to use in all request (Default: "git.cs.kau.se/rasmoste/ct-sans")
+ -a, --http-agent: HTTP agent to use in all request (Default: "rgdd.se/ct-sans")
-m, --metrics: How often to emit metrics to stderr (Default: 16s)
Asemble options:
@@ -104,7 +104,7 @@ func main() {
ctflag.Uint64(&fs, &opts.WorkersPerLog, "workers", "w", 2)
ctflag.Uint64(&fs, &opts.PersistSize, "batch-disk", "k", 256)
ctflag.Uint64(&fs, &opts.BatchSize, "batch-req", "q", 128)
- ctflag.String(&fs, &opts.HTTPAgent, "http-agent", "a", "git.cs.kau.se/rasmoste/ct-sans")
+ ctflag.String(&fs, &opts.HTTPAgent, "http-agent", "a", "rgdd.se/ct-sans")
ctflag.Duration(&fs, &opts.MetricsInterval, "metrics", "m", 16*time.Second)
ctflag.Uint64(&fs, &opts.BufferSize, "buffer-size", "b", 1)
@@ -2,7 +2,7 @@
// Install:
//
-// go install git.cs.kau.se/rasmoste/ct-sans@latest
+// go install rgdd.se/ct-sans@latest
//
// Usage: